@@ -3,6 +3,7 @@
 from PyQt4 import QtCore, QtGui
 from qtUImain import Ui_MainWindow
 from sys import argv
+from os import path
 
 import Options
 from mingus.core import diatonic
@@ -48,11 +49,43 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			self.ui.key.addItem(x)
 
 	def connect_widgets(self):
-		self.connect(self.ui.startbutton, QtCore.SIGNAL("clicked()"), self.start_simulation)
+		self.connect(self.ui.startbutton, 
+			QtCore.SIGNAL("clicked()"), 
+			self.start_simulation)
+		self.connect(self.ui.addblockbutton,
+			QtCore.SIGNAL("clicked()"),
+			self.add_block)
+		self.connect(self.ui.addprogressionbutton,
+			QtCore.SIGNAL("clicked()"),
+			self.add_progression)
+		self.connect(self.ui.addinstrumentbutton,
+			QtCore.SIGNAL("clicked()"),
+			self.add_instrument)
 
 	def set_defaults(self):
-		self.ui.resolution.setCurrentIndex(3)
-		self.ui.key.setCurrentIndex(6)
+		self.ui.resolution.setCurrentIndex(3) # '8'
+		self.ui.key.setCurrentIndex(6) # 'C'
+	
+	def add_block(self):
+		self.ui.blocks.addItem(self.ui.blockcombo.currentText())
+
+	def add_progression(self):
+		self.ui.progressions.addItem(
+			self.ui.progressioncombo.currentText())
+
+	def add_instrument(self):
+		self.ui.instruments.addItem(
+			self.ui.instrumentcombo.currentText())
+
+	def get_file_name(self, name, n = 0):
+		if n == 0:
+			midi = name + ".mid"
+		else:
+			midi = name + str(n) + ".mid"
+		if path.exists(midi):
+			return self.get_file_name(name, n + 1)
+		else:
+			return midi
 
 	def start_simulation(self):
 		o = OptionClass()
@@ -64,6 +97,11 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		o.loop = int(self.ui.loop.value())
 		o.wild = float(self.ui.wildness.value())
 		o.swing = self.ui.swing.checkState()
+		o.no_fluidsynth = self.ui.no_fluidsynth.checkState()
+
+		project = str(self.ui.projectname.text())
+		o.midifile = self.get_file_name(project)
+
 		seq = Options.get_sequencer(o)
 		seq.play()
 
